==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
                WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebPaneDragEndEventArgsDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        }
        static d(a) {
            WebPaneDragEndEventArgsDescriptionMetadata.b(a);
            a.u("WebPaneDragEndEventArgs", () => new WebPaneDragEndEventArgsDescription());
            a.t("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragEndEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragEndEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragEndEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
                WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPaneDragEndEventArgsDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        }
        static d(a) {
            WebPaneDragEndEventArgsDescriptionMetadata.b(a);
            a.aa("WebPaneDragEndEventArgs", () => new WebPaneDragEndEventArgsDescription());
            a.z("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragEndEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
})();
